@@ -7,7 +7,11 @@ class Method(ExtendedEnum):
     """HTTP Methods"""
 
     GET = "GET"
+    HEAD = "HEAD"
     POST = "POST"
     PUT = "PUT"
     DELETE = "DELETE"
+    CONNECT = "CONNECT"
     PATCH = "PATCH"
+    TRACE = "TRACE"
+    OPTIONS = "OPTIONS"
